@@ -275,13 +275,17 @@ const char *s_basic_modes[] = {
 	(char *) "THOR50x1",
 	(char *) "THOR50x2",
 	(char *) "THOR100",
+	(char *) "THOR11",
+	(char *) "THOR32",
+	(char *) "THOR44",
+	(char *) "THOR56",
 	(char *) 0
 };
 
 char *s_modes[sizeof(s_basic_modes)/sizeof(char *)];
 
 /** ********************************************************
- * A string table of event types
+ * A std::string table of event types
  ***********************************************************/
 const char *event_types[] = {
 	(char *) "5 min",
@@ -303,7 +307,7 @@ std::string valid_modes;
  ***********************************************************/
 bool valid_mode_check(std::string &md)
 {
-	return (valid_modes.find(md) != string::npos);
+	return (valid_modes.find(md) != std::string::npos);
 }
 
 /** ********************************************************
@@ -358,7 +362,7 @@ void update_cbo_modes(std::string &fldigi_modes)
  ***********************************************************/
 void init_cbo_modes()
 {
-	string min_modes;
+	std::string min_modes;
 	min_modes.assign("DOMX22|MFSK16|MFSK22|MFSK31|MFSK32|");
 	min_modes.append("MT63-500S|MT63-1KS|MT63-2KS|");
 	min_modes.append("MT63-500L|MT63-1KL|MT63-2KL|");
@@ -366,7 +370,7 @@ void init_cbo_modes()
 	min_modes.append("PSK125R|PSK250R|PSK500R|");
 	min_modes.append("Olivia-4-250|Olivia-4-500|Olivia-8-250|Olivia-8-500|");
 	min_modes.append("Olivia-8-1K|Olivia-16-500|Olivia-16-1K|");
-	min_modes.append("THOR16|THOR22");
+	min_modes.append("THOR11|THOR16|THOR22|THOR32|THOR44|THOR56|THOR25x4|THOR50x1|THOR50x2|THOR100|");
 	update_cbo_modes(min_modes);
 }
 
@@ -468,7 +472,7 @@ void cb_mnuCmdLineParams(void *, void *)
 		wCmdLine->begin();
 		Fl_Browser *bwsCmds = new Fl_Browser(2,2,600,400,"");
 		int i = 0;
-		string cmdline;
+		std::string cmdline;
 		while (options[i] != NULL) {
 			cmdline.assign("@f").append(options[i]);
 			bwsCmds->add(cmdline.c_str());
