@@ -41,12 +41,11 @@
 //#define DEBUG 1
 #undef DEBUG
 
-using namespace std;
 
 
 typedef struct {
 	void *widget;
-	string strValue;
+	std::string strValue;
 } STRING_VALUE;
 
 typedef struct {
@@ -82,10 +81,10 @@ extern pthread_mutex_t mutex_file_io;
 extern pthread_mutex_t mutex_xmlrpc;
 extern pthread_t *xmlrpc_thread;
 
-extern string buffer;
-extern string flamp_dir;
-extern string flampHomeDir;
-extern string title;
+extern std::string buffer;
+extern std::string flamp_dir;
+extern std::string flampHomeDir;
+extern std::string title;
 
 extern bool do_events_flag;
 extern bool tx_ztimer_flag;
@@ -147,4 +146,10 @@ extern void turn_rsid_on(void);
 extern void tx_removefile(bool flag);
 extern void update_cAmp_changes(cAmp *amp);
 extern void writefile(int);
+
+extern void xml_execute_script(std::string);
+extern int  xml_create_script(std::string script_path_name, std::string text);
+extern void start_server(int);
+extern void exit_server();
+
 #endif
