@@ -1256,4 +1256,38 @@ void script_execute(void *v) {
 	Fl::unlock();
 }
 
+/** **************************************************************
+ * \brief Execute a configuration script from an xmlrpc procedure.
+ * \param std::string script_path_filename
+ *****************************************************************/
+ 
+#include <fstream>
+
+void xml_execute_script(std::string script_path_name)
+{
+	std::cout << "xml_execute_script( " << script_path_name << " )\n";
+
+	pthread_mutex_lock(&mutex_script_io);
+
+	Fl::lock();
+	script_execute(script_path_name.c_str(), false);
+	Fl::unlock();
+
+	show_selected_xmt(1);
+
+	pthread_mutex_unlock(&mutex_script_io);
+}
+
+int xml_create_script(std::string script_path_name, std::string text)
+{
+	try {
+		std::ofstream oscript(script_path_name.c_str());
+		oscript << text;
+		oscript.close();
+		return 1;
+	} catch (...) {
+		LOG_ERROR("Could not create %s", script_path_name.c_str());
+		return 0;
+	}
+}
 
