@@ -40,7 +40,6 @@
 #include "util.h"
 #include "gettext.h"
 
-using namespace std;
 
 Font_Browser* font_browser;
 
@@ -289,7 +288,7 @@ void Font_Browser::fontFilter(filter_t filter)
 
 	int s = lst_Font->size();
 
-	static vector<bool> fixed;
+	static std::vector<bool> fixed;
 	if (fixed.empty()) {
 		Progress_Window pw(1, s, _("Reading fonts..."));
 		fixed.resize(s);
