@@ -26,7 +26,7 @@
 #include <ostream>
 #include <stdlib.h>
 #include <stdio.h>
-
+#include <string.h>
 
 namespace XmlRpc {
 
@@ -156,7 +156,7 @@ namespace XmlRpc {
   // Predicate for tm equality
   static bool tmEq(struct tm const& t1, struct tm const& t2) {
     return t1.tm_sec == t2.tm_sec && t1.tm_min == t2.tm_min &&
-            t1.tm_hour == t2.tm_hour && t1.tm_mday == t1.tm_mday &&
+            t1.tm_hour == t2.tm_hour && t1.tm_mday == t2.tm_mday &&
             t1.tm_mon == t2.tm_mon && t1.tm_year == t2.tm_year;
   }
 
@@ -485,10 +485,10 @@ namespace XmlRpc {
   std::string XmlRpcValue::timeToXml() const
   {
     struct tm* t = _value.asTime;
-    char buf[20];
+    char buf[50];
+    memset(buf, 0, 50);
     snprintf(buf, sizeof(buf)-1, "%04d%02d%02dT%02d:%02d:%02d", 
       1900+t->tm_year,1+t->tm_mon,t->tm_mday,t->tm_hour,t->tm_min,t->tm_sec);
-    buf[sizeof(buf)-1] = 0;
 
     return std::string("<value><dateTime.iso8601>") + buf + std::string("</dateTime.iso8601></value>");
   }
